# Generated by Django 2.0.8 on 2018-09-22 22:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtaillinkchecker', '0004_auto_20180829_1922'),
    ]

    operations = [
        migrations.AlterField(
            model_name='scanlink',
            name='url',
            field=models.URLField(max_length=500),
        ),
    ]
